==> com_clubmanagement_1.1.zip: admin/views/people/tmpl/form.php <==
<?php defined('_JEXEC') or die('Restricted access'); ?>

<?php
$people = $this->items[0];
//print_r($people);
$params = $this->params;
//print_r($params->get( 'foldertree' ));

?>
<script type="text/javascript">
jQuery.noConflict();
jQuery(document).ready(function(){
	jQuery("table input.calendar").datepicker({dateFormat: 'yy-mm-dd'});
});
</script>

<form action="index.php" method="post" name="adminForm" id="adminForm">
<div>
	<fieldset class="adminform">
	<legend><?php echo JText::_( 'COM_CLUBMANAGEMENT_DETAILS' ); ?></legend>
	<table class="admintable" style="width:100%;">
		<tr>
			<th width="110" class="key"><label for="name"><?php echo JText::_( 'COM_CLUBMANAGEMENT_NAME' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="name" id="name" size="60" value="<?php echo $people->name; ?>" /></td>
			<td rowspan="10" style="vertical-align: top;"><?php
			$tmp = str_replace(array(JURI::root(), '/'), array(JPATH_ROOT, DS), JURI::root().$people->passportPhotograph);
			if (!empty($people->passportPhotograph) && file_exists($tmp )) {
				?><img style="display: block;" class="passportPhotograph" src="<?php echo JURI::root(TRUE).$people->passportPhotograph;?>" alt="<?php echo $people->name_complete;?>" title="<?php echo $people->name_complete;?>"/><?php
			}
			?></td>
		</tr>
		<tr>
			<th width="110" class="key"><label for="surname"><?php echo JText::_( 'COM_CLUBMANAGEMENT_SURNAME' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="surname" id="surname" size="60" value="<?php echo $people->surname; ?>" /></td>
		</tr>
		<tr>
			<th class="key"><label for="birthday"><?php echo JText::_( 'COM_CLUBMANAGEMENT_BIRTHDAY' ); ?>:</label></th>
			<td><?php echo JHtml::_('calendar', $people->birthday, 'birthday', "birthday", '%Y-%m-%d'); ?></td>
		</tr>
		<tr>
			<th class="key"><label for="address"><?php echo JText::_( 'COM_CLUBMANAGEMENT_ADDRESS' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="address" id="address" size="60" value="<?php echo $people->address; ?>" /></td>
		</tr>
		<tr>
			<th class="key"><label for="zipcode"><?php echo JText::_( 'COM_CLUBMANAGEMENT_ZIPCODE' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="zipcode" id="zipcode" size="60" value="<?php echo $people->zipcode; ?>" /></td>
		</tr>
		<tr>
			<th class="key"><label for="city"><?php echo JText::_( 'COM_CLUBMANAGEMENT_CITY' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="city" id="city" size="60" value="<?php echo $people->city; ?>" /></td>
		</tr>
		<tr>
			<th class="key"><label for="country"><?php echo JText::_( 'COM_CLUBMANAGEMENT_COUNTRY' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="country" id="country" size="60" value="<?php echo $people->country; ?>" /></td>
		</tr>
		<tr>
			<th width="120" class="key"><?php echo JText::_( 'COM_CLUBMANAGEMENT_SEX' ); ?>:</th>
			<td><?php 
			$s = array(
				(object) array("value"=>"m", "text"=>JText::_("COM_CLUBMANAGEMENT_MALE")),
				(object) array("value"=>"f", "text"=>JText::_("COM_CLUBMANAGEMENT_FEMALE"))
			);
			echo JHTML::_( 'select.radiolist',  $s, 'sex', $attr, "value", "text", $people->sex);
			?></td>
		</tr>
		<tr>
			<th class="key"><label for="joomlauser"><?php echo JText::_( 'COM_CLUBMANAGEMENT_JOOMLAUSER' ); ?>:</label></th>
			<td><?php echo JHTML::_('list.users', "joomlauser", $people->joomlauser, TRUE); ?></td>
		</tr>
		<tr>
			<th class="key"><label for="passportPhotograph"><?php echo JText::_( 'COM_CLUBMANAGEMENT_PASSPORTPHOTOGRAPH' ); ?>:</label></th>
			<td><?php 
				$images = JFolder::files(JPATH_ROOT.DS.$params->get('foldertree'), "\.png$|\.gif$|\.jpg$|\.bmp$|\.ico$", $params->get('recursive_folder_search'), TRUE);
				$objlist = array();
				for($i=0; $i<count($images); $i++) {
					$tmp = str_replace(array(JPATH_ROOT, DS), array('', '/'), $images[$i]);
					$objlist[] = (object) array('id'=>$tmp, 'text'=>$tmp);
				}
				array_unshift($objlist, array('id'=>0, 'text'=>JText::_('COM_CLUBMANAGEMENT_SHOWALL')));
				echo JHTML::_( 'select.genericlist',  $objlist, 'passportPhotograph', $attr, "id", "text", $people->passportPhotograph);
			?></td>
		</tr>
	</table>
	</fieldset>
	<fieldset>
		<legend><?php echo JText::_('PARAMETERS');?></legend>
		<table>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_TOURNAMENTS');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_tournaments]', $attr, $params->get('show_tournaments'), JText::_('YES'), JText::_('NO'), 'params_show_tournaments'); ?></td>
			</tr>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_CONTACTS');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_contacts]', $attr, $params->get('show_contacts'), JText::_('YES'), JText::_('NO'), 'params_show_contacts'); ?></td>
			</tr>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_POSITIONS');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_positions]', $attr, $params->get('show_positions'), JText::_('YES'), JText::_('NO'), 'params_show_positions'); ?></td>
			</tr>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_MEMBERSHIPS');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_memberships]', $attr, $params->get('show_memberships'), JText::_('YES'), JText::_('NO'), 'params_show_memberships'); ?></td>
			</tr>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_PASSPORTPHOTOGRAPH');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_passportPhotograph]', $attr, $params->get('show_passportPhotograph'), JText::_('YES'), JText::_('NO'), 'params_show_passportPhotograph'); ?></td>
			</tr>
		</table>
	</fieldset>
</div>
<div class="clr"></div>
<div class="clr"></div>

<input type="hidden" name="option" value="com_clubmanagement" />
<input type="hidden" name="view" value="people" />
<input type="hidden" name="people_id" value="<?php echo $people->people_id; ?>" />
<input type="hidden" name="task" value="" />
</form>

==> com_clubmanagement_1.3.zip: admin/views/people/tmpl/form.php <==
<?php defined('_JEXEC') or die('Restricted access'); ?>

<?php
$people = $this->items[0];
//print_r($people);
$params = $this->params;
//print_r($params->get( 'foldertree' ));

$attr="";
?>

<script type="text/javascript">
jQuery.noConflict();
jQuery(document).ready(function(){
	jQuery("table input.calendar").datepicker({dateFormat: 'yy-mm-dd'});
});
</script>

<form action="index.php" method="post" name="adminForm" id="adminForm">
<div>
	<fieldset class="adminform">
	<legend><?php echo JText::_( 'COM_CLUBMANAGEMENT_DETAILS' ); ?></legend>
	<table class="admintable" style="width:100%;">
		<tr>
			<th width="110" class="key"><label for="name"><?php echo JText::_( 'COM_CLUBMANAGEMENT_NAME' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="name" id="name" size="60" value="<?php echo $people->name; ?>" /></td>
			<td rowspan="10" style="vertical-align: top;"><?php
			$tmp = str_replace(array(JURI::root(), '/'), array(JPATH_ROOT, DS), JURI::root().$people->passportPhotograph);
			if (!empty($people->passportPhotograph) && file_exists($tmp )) {
				?><img style="display: block;" class="passportPhotograph" src="<?php echo JURI::root(TRUE).$people->passportPhotograph;?>" alt="<?php echo $people->name_complete;?>" title="<?php echo $people->name_complete;?>"/><?php
			}
			?></td>
		</tr>
		<tr>
			<th width="110" class="key"><label for="surname"><?php echo JText::_( 'COM_CLUBMANAGEMENT_SURNAME' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="surname" id="surname" size="60" value="<?php echo $people->surname; ?>" /></td>
		</tr>
		<tr>
			<th class="key"><label for="birthday"><?php echo JText::_( 'COM_CLUBMANAGEMENT_BIRTHDAY' ); ?>:</label></th>
			<td><?php echo JHtml::_('calendar', $people->birthday, 'birthday', "birthday", '%Y-%m-%d'); ?></td>
		</tr>
		<tr>
			<th class="key"><label for="address"><?php echo JText::_( 'COM_CLUBMANAGEMENT_ADDRESS' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="address" id="address" size="60" value="<?php echo $people->address; ?>" /></td>
		</tr>
		<tr>
			<th class="key"><label for="zipcode"><?php echo JText::_( 'COM_CLUBMANAGEMENT_ZIPCODE' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="zipcode" id="zipcode" size="60" value="<?php echo $people->zipcode; ?>" /></td>
		</tr>
		<tr>
			<th class="key"><label for="city"><?php echo JText::_( 'COM_CLUBMANAGEMENT_CITY' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="city" id="city" size="60" value="<?php echo $people->city; ?>" /></td>
		</tr>
		<tr>
			<th class="key"><label for="country"><?php echo JText::_( 'COM_CLUBMANAGEMENT_COUNTRY' ); ?>:</label></th>
			<td><input class="inputbox" type="text" name="country" id="country" size="60" value="<?php echo $people->country; ?>" /></td>
		</tr>
		<tr>
			<th width="120" class="key"><?php echo JText::_( 'COM_CLUBMANAGEMENT_SEX' ); ?>:</th>
			<td><?php 
			$s = array(
				(object) array("value"=>"m", "text"=>JText::_("COM_CLUBMANAGEMENT_MALE")),
				(object) array("value"=>"f", "text"=>JText::_("COM_CLUBMANAGEMENT_FEMALE"))
			);
			echo JHTML::_( 'select.radiolist',  $s, 'sex', $attr, "value", "text", $people->sex);
			?></td>
		</tr>
		<tr>
			<th class="key"><label for="joomlauser"><?php echo JText::_( 'COM_CLUBMANAGEMENT_JOOMLAUSER' ); ?>:</label></th>
			<td><?php echo JHTML::_('list.users', "joomlauser", $people->joomlauser, TRUE); ?></td>
		</tr>
		<tr>
			<th class="key"><label for="passportPhotograph"><?php echo JText::_( 'COM_CLUBMANAGEMENT_PASSPORTPHOTOGRAPH' ); ?>:</label></th>
			<td><?php 
				$images = JFolder::files(JPATH_ROOT.DS.$params->get('foldertree'), "\.png$|\.gif$|\.jpg$|\.bmp$|\.ico$", $params->get('recursive_folder_search'), TRUE);
				$objlist = array();
				for($i=0; $i<count($images); $i++) {
					$tmp = str_replace(array(JPATH_ROOT, DS), array('', '/'), $images[$i]);
					$objlist[] = (object) array('id'=>$tmp, 'text'=>$tmp);
				}
				array_unshift($objlist, array('id'=>0, 'text'=>JText::_('COM_CLUBMANAGEMENT_SHOWALL')));
				echo JHTML::_( 'select.genericlist',  $objlist, 'passportPhotograph', $attr, "id", "text", $people->passportPhotograph);
			?></td>
		</tr>
	</table>
	</fieldset>
	<fieldset>
		<legend><?php echo JText::_('PARAMETERS');?></legend>
		<table>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_TOURNAMENTS');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_tournaments]', $attr, $params->get('show_tournaments'), JText::_('JYES'), JText::_('JNO'), 'params_show_tournaments'); ?></td>
			</tr>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_CONTACTS');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_contacts]', $attr, $params->get('show_contacts'), JText::_('JYES'), JText::_('JNO'), 'params_show_contacts'); ?></td>
			</tr>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_POSITIONS');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_positions]', $attr, $params->get('show_positions'), JText::_('JYES'), JText::_('JNO'), 'params_show_positions'); ?></td>
			</tr>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_MEMBERSHIPS');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_memberships]', $attr, $params->get('show_memberships'), JText::_('JYES'), JText::_('JNO'), 'params_show_memberships'); ?></td>
			</tr>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_PASSPORTPHOTOGRAPH');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_passportPhotograph]', $attr, $params->get('show_passportPhotograph'), JText::_('JYES'), JText::_('JNO'), 'params_show_passportPhotograph'); ?></td>
			</tr>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_BIRTHDAY');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_birthday]', $attr, $params->get('show_birthday'), JText::_('JYES'), JText::_('JNO'), 'params_show_birthday'); ?></td>
			</tr>
			<tr>
				<th><label><?php echo JText::_('COM_CLUBMANAGEMENT_SHOW_ADDRESS');?></label></th>
				<td><?php echo JHTML::_( 'select.booleanlist', 'params[show_address]', $attr, $params->get('show_address'), JText::_('JYES'), JText::_('JNO'), 'params_show_address'); ?></td>
			</tr>
		</table>
	</fieldset>
</div>
<div class="clr"></div>
<div class="clr"></div>

<input type="hidden" name="option" value="com_clubmanagement" />
<input type="hidden" name="view" value="people" />
<input type="hidden" name="people_id" value="<?php echo $people->people_id; ?>" />
<input type="hidden" name="task" value="" />
</form>
